@@ -6,12 +6,13 @@ import sys
 class ConfigError(Exception):
     def __init__     (self, message): ...
     def __terminate__():              ...
+    def add_prefix   (self, prefix):  ...
 
 
 
 @member(ConfigError)
 def __init__(self, message):
-    self.args = [message]
+    self.args = [f"{red(bold("fatal error:"))} {message}"]
     on_terminate(ConfigError.__terminate__)
 
 @member(ConfigError)
@@ -19,4 +20,11 @@ def __terminate__():
     try:
         rethrow_exception(current_exception())
     except ConfigError as error:
-        print(f"{red(bold("fatal error:"))} {error}", file=sys.stderr)
+        print(error, file=sys.stderr)
+
+@member(ConfigError)
+def add_prefix(self, prefix):
+    prefixed = ConfigError(*self.args)
+    if not prefixed.args[0].startswith(prefix):
+        prefixed.args = [prefix + '\n' + self.args[0]]
+    return prefixed
\ No newline at end of file
